@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # example how to deal with the depcache
 
 import apt
@@ -8,7 +8,6 @@ from apt.progress import InstallProgress
 
 
 class TextInstallProgress(InstallProgress):
-
     def __init__(self):
         apt.progress.InstallProgress.__init__(self)
         self.last = 0.0
@@ -22,10 +21,10 @@ class TextInstallProgress(InstallProgress):
         self.last = self.percent
 
     def conffile(self, current, new):
-        print "conffile prompt: %s %s" % (current, new)
+        print("conffile prompt: %s %s" % (current, new))
 
     def error(self, errorstr):
-        print "got dpkg error: '%s'" % errorstr
+        print("got dpkg error: '%s'" % errorstr)
 
 
 cache = apt.Cache(apt.progress.OpTextProgress())
@@ -37,12 +36,12 @@ pkg = cache["3dchess"]
 
 # install or remove, the importend thing is to keep us busy :)
 if pkg.is_installed:
-    print "Going to delete %s" % pkg.name
+    print("Going to delete %s" % pkg.name)
     pkg.mark_delete()
 else:
-    print "Going to install %s" % pkg.name
+    print("Going to install %s" % pkg.name)
     pkg.mark_install()
 res = cache.commit(fprogress, iprogress)
-print res
+print(res)
 
 sys.exit(0)
