@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 """Emulate dpkg --extract package.deb outdir"""
 
 from __future__ import print_function
@@ -15,8 +15,7 @@ def main():
         print("Usage: %s package.deb outdir\n" % (__file__), file=sys.stderr)
         sys.exit(1)
     if not os.path.exists(sys.argv[2]):
-        print("The directory %s does not exist\n" % (sys.argv[2]),
-              file=sys.stderr)
+        print("The directory %s does not exist\n" % (sys.argv[2]), file=sys.stderr)
         sys.exit(1)
 
     fobj = open(sys.argv[1])
@@ -25,5 +24,6 @@ def main():
     finally:
         fobj.close()
 
+
 if __name__ == "__main__":
     main()
