@@ -127,6 +127,38 @@ PyTypeObject PyArMember_Type = {
     armember_getset,                     // tp_getset
 };
 
+
+static const char *filefd_doc=
+   "Internal helper type, representing a FileFd.";
+PyTypeObject PyFileFd_Type = {
+    PyVarObject_HEAD_INIT(&PyType_Type, 0)
+    "apt_inst.__FileFd"        ,                 // tp_name
+    sizeof(CppPyObject<FileFd>),         // tp_basicsize
+    0,                                        // tp_itemsize
+    // Methods
+    CppDealloc<FileFd>,                  // tp_dealloc
+    0,                                   // tp_print
+    0,                                   // tp_getattr
+    0,                                   // tp_setattr
+    0,                                   // tp_compare
+    0,                                   // tp_repr
+    0,                                   // tp_as_number
+    0,                                   // tp_as_sequence
+    0,                                   // tp_as_mapping
+    0,                                   // tp_hash
+    0,                                   // tp_call
+    0,                                   // tp_str
+    0,                                   // tp_getattro
+    0,                                   // tp_setattro
+    0,                                   // tp_as_buffer
+    Py_TPFLAGS_DEFAULT |                 // tp_flags
+    Py_TPFLAGS_HAVE_GC,
+    filefd_doc,                          // tp_doc
+    CppTraverse<FileFd>,                 // tp_traverse
+    CppClear<FileFd>,                    // tp_clear
+};
+
+
 // We just add an inline method and should thus be ABI compatible in a way that
 // we can simply cast ARArchive instances to PyARArchiveHack.
 class PyARArchiveHack : public ARArchive
@@ -138,7 +170,7 @@ public:
 };
 
 struct PyArArchiveObject : public CppPyObject<PyARArchiveHack*> {
-    FileFd Fd;
+    CppPyObject<FileFd> *Fd;
 };
 
 static const char *ararchive_getmember_doc =
@@ -184,7 +216,7 @@ static PyObject *ararchive_extractdata(PyArArchiveObject *self, PyObject *args)
                      "Member '%s' is too large to read into memory",name.path);
         return 0;
     }
-    if (!self->Fd.Seek(member->Start))
+    if (!self->Fd->Object.Seek(member->Start))
         return HandleErrors();
 
     char* value;
@@ -195,7 +227,7 @@ static PyObject *ararchive_extractdata(PyArArchiveObject *self, PyObject *args)
                      "Member '%s' is too large to read into memory",name.path);
         return 0;
     }
-    self->Fd.Read(value, member->Size, true);
+    self->Fd->Object.Read(value, member->Size, true);
     PyObject *result = PyBytes_FromStringAndSize(value, member->Size);
     delete[] value;
     return result;
@@ -273,7 +305,7 @@ static PyObject *ararchive_extract(PyArArchiveObject *self, PyObject *args)
         PyErr_Format(PyExc_LookupError,"No member named '%s'",name.path);
         return 0;
     }
-    return _extract(self->Fd, member, target);
+    return _extract(self->Fd->Object, member, target);
 }
 
 static const char *ararchive_extractall_doc =
@@ -292,7 +324,7 @@ static PyObject *ararchive_extractall(PyArArchiveObject *self, PyObject *args)
     const ARArchive::Member *member = self->Object->Members();
 
     do {
-        if (_extract(self->Fd, member, target) == 0)
+        if (_extract(self->Fd->Object, member, target) == 0)
             return 0;
     } while ((member = member->Next));
     Py_RETURN_TRUE;
@@ -319,10 +351,10 @@ static PyObject *ararchive_gettar(PyArArchiveObject *self, PyObject *args)
         return 0;
     }
 
-    PyTarFileObject *tarfile = (PyTarFileObject*)CppPyObject_NEW<ExtractTar*>(self,&PyTarFile_Type);
-    new (&tarfile->Fd) FileFd(self->Fd.Fd());
+    PyTarFileObject *tarfile = (PyTarFileObject*)CppPyObject_NEW<ExtractTar*>(self->Fd,&PyTarFile_Type);
+    new (&tarfile->Fd) FileFd(self->Fd->Object.Fd());
     tarfile->min = member->Start;
-    tarfile->Object = new ExtractTar(self->Fd, member->Size, comp);
+    tarfile->Object = new ExtractTar(self->Fd->Object, member->Size, comp);
     return HandleErrors(tarfile);
 }
 
@@ -389,36 +421,52 @@ static PyObject *ararchive_new(PyTypeObject *type, PyObject *args,
                                PyObject *kwds)
 {
     PyObject *file;
-    PyArArchiveObject *self;
     PyApt_Filename filename;
     int fileno;
     if (PyArg_ParseTuple(args,"O:__new__",&file) == 0)
         return 0;
 
+    PyApt_UniqueObject<PyArArchiveObject> self(NULL);
     // We receive a filename.
     if (filename.init(file)) {
-        self = (PyArArchiveObject *)CppPyObject_NEW<ARArchive*>(0,type);
-        new (&self->Fd) FileFd(filename,FileFd::ReadOnly);
+        self.reset((PyArArchiveObject*) CppPyObject_NEW<ARArchive*>(0,type));
+        self->Fd = CppPyObject_NEW<FileFd>(NULL, &PyFileFd_Type);
+        new (&self->Fd->Object) FileFd(filename,FileFd::ReadOnly);
     }
     // We receive a file object.
     else if ((fileno = PyObject_AsFileDescriptor(file)) != -1) {
         // Clear the error set by PyObject_AsString().
         PyErr_Clear();
-        self = (PyArArchiveObject *)CppPyObject_NEW<ARArchive*>(file,type);
-        new (&self->Fd) FileFd(fileno,false);
+        self.reset((PyArArchiveObject*) CppPyObject_NEW<ARArchive*>(NULL,type));
+        self->Fd = CppPyObject_NEW<FileFd>(file, &PyFileFd_Type);
+        new (&self->Fd->Object) FileFd(fileno,false);
     }
     else {
         return 0;
     }
-    self->Object = (PyARArchiveHack*)new ARArchive(self->Fd);
+    self->Object = (PyARArchiveHack*)new ARArchive(self->Fd->Object);
     if (_error->PendingError() == true)
         return HandleErrors();
-    return self;
+    return self.release();
+}
+
+static int ararchive_traverse(PyObject *_self, visitproc visit, void* arg)
+{
+    PyArArchiveObject *self = (PyArArchiveObject*)_self;
+    Py_VISIT(self->Fd);
+    return CppTraverse<ARArchive*>(self, visit, arg);
+}
+
+static int ararchive_clear(PyObject *_self)
+{
+    PyArArchiveObject *self = (PyArArchiveObject*)_self;
+    Py_CLEAR(self->Fd);
+    return CppClear<ARArchive*>(self);
 }
 
 static void ararchive_dealloc(PyObject *self)
 {
-    ((PyArArchiveObject *)(self))->Fd.~FileFd();
+    ararchive_clear(self);
     CppDeallocPtr<ARArchive*>(self);
 }
 
@@ -472,8 +520,8 @@ PyTypeObject PyArArchive_Type = {
     Py_TPFLAGS_DEFAULT |                 // tp_flags
     Py_TPFLAGS_HAVE_GC,
     ararchive_doc,                       // tp_doc
-    CppTraverse<ARArchive*>,        // tp_traverse
-    CppClear<ARArchive*>,           // tp_clear
+    ararchive_traverse,                  // tp_traverse
+    ararchive_clear,                     // tp_clear
     0,                                   // tp_richcompare
     0,                                   // tp_weaklistoffset
     (getiterfunc)ararchive_iter,         // tp_iter
@@ -528,10 +576,10 @@ static PyObject *_gettar(PyDebFileObject *self, const ARArchive::Member *m,
 {
     if (!m)
         return 0;
-    PyTarFileObject *tarfile = (PyTarFileObject*)CppPyObject_NEW<ExtractTar*>(self,&PyTarFile_Type);
-    new (&tarfile->Fd) FileFd(self->Fd.Fd());
+    PyTarFileObject *tarfile = (PyTarFileObject*)CppPyObject_NEW<ExtractTar*>(self->Fd,&PyTarFile_Type);
+    new (&tarfile->Fd) FileFd(self->Fd->Object.Fd());
     tarfile->min = m->Start;
-    tarfile->Object = new ExtractTar(self->Fd, m->Size, comp);
+    tarfile->Object = new ExtractTar(self->Fd->Object, m->Size, comp);
     return tarfile;
 }
 
@@ -552,7 +600,7 @@ static PyObject *debfile_get_tar(PyDebFileObject *self, const char *Name)
         Member = AR.FindMember(std::string(Name).append(c->Extension).c_str());
         if (Member == NULL)
             continue;
-        Compressor = c->Binary;
+        Compressor = c->Name;
         break;
     }
 
@@ -578,16 +626,16 @@ static PyObject *debfile_get_tar(PyDebFileObject *self, const char *Name)
 
 static PyObject *debfile_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 {
-    PyDebFileObject *self = (PyDebFileObject*)ararchive_new(type, args, kwds);
+    PyApt_UniqueObject<PyDebFileObject> self((PyDebFileObject*)ararchive_new(type, args, kwds));
     if (self == NULL)
         return NULL;
 
     // DebFile
-    self->control = debfile_get_tar(self, "control.tar");
+    self->control = debfile_get_tar(self.get(), "control.tar");
     if (self->control == NULL)
         return NULL;
 
-    self->data = debfile_get_tar(self, "data.tar");
+    self->data = debfile_get_tar(self.get(), "data.tar");
     if (self->data == NULL)
         return NULL;
 
@@ -596,14 +644,14 @@ static PyObject *debfile_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
         return PyErr_Format(PyAptError, "No debian archive, missing %s",
                             "debian-binary");
 
-    if (!self->Fd.Seek(member->Start))
+    if (!self->Fd->Object.Seek(member->Start))
         return HandleErrors();
 
     char* value = new char[member->Size];
-    self->Fd.Read(value, member->Size, true);
+    self->Fd->Object.Read(value, member->Size, true);
     self->debian_binary = PyBytes_FromStringAndSize(value, member->Size);
     delete[] value;
-    return self;
+    return self.release();
 }
 
 static int debfile_traverse(PyObject *_self, visitproc visit, void* arg)
