@@ -16,8 +16,7 @@ class TestAptSourcesPorts(testcommon.TestCase):
     def setUp(self):
         testcommon.TestCase.setUp(self)
         apt_pkg.config.set("APT::Architecture", "powerpc")
-        apt_pkg.config.set("Dir::Etc",
-                           os.path.abspath("data/aptsources_ports"))
+        apt_pkg.config.set("Dir::Etc", os.path.abspath("data/aptsources_ports"))
         apt_pkg.config.set("Dir::Etc::sourceparts", tempfile.mkdtemp())
         if os.path.exists("../build/data/templates"):
             self.templates = os.path.abspath("../build/data/templates")
@@ -28,8 +27,7 @@ class TestAptSourcesPorts(testcommon.TestCase):
         """aptsources_ports: Test matcher."""
         apt_pkg.config.set("Dir::Etc::sourcelist", "sources.list")
         sources = aptsources.sourceslist.SourcesList(True, self.templates)
-        distro = aptsources.distro.get_distro("Ubuntu", "hardy", "desc",
-                                              "8.04")
+        distro = aptsources.distro.get_distro("Ubuntu", "hardy", "desc", "8.04")
         distro.get_sources(sources)
         # test if all suits of the current distro were detected correctly
         for s in sources:
