@@ -11,7 +11,6 @@ Unit tests to verify the correctness of Hashes, HashString and the various
 functions like md5sum."""
 import unittest
 import hashlib
-import sys
 import warnings
 
 import apt_pkg
@@ -61,39 +60,38 @@ class TestHashes(testcommon.TestCase):
 
     def test_bytes(self):
         """hashes: Test apt_pkg.Hashes(bytes)"""
-        self.assertEqual(self.hashes.hashes.find("md5sum").hashvalue,
-                         self.md5)
-        self.assertEqual(self.hashes.hashes.find("md5sum"),
-                         apt_pkg.HashString("MD5Sum", self.md5))
-        self.assertEqual(self.hashes.hashes.find("sha1"),
-                         apt_pkg.HashString("SHA1", self.sha1))
-        self.assertEqual(self.hashes.hashes.find("sha256"),
-                         apt_pkg.HashString("SHA256", self.sha256))
+        self.assertEqual(self.hashes.hashes.find("md5sum").hashvalue, self.md5)
+        self.assertEqual(
+            self.hashes.hashes.find("md5sum"), apt_pkg.HashString("MD5Sum", self.md5)
+        )
+        self.assertEqual(
+            self.hashes.hashes.find("sha1"), apt_pkg.HashString("SHA1", self.sha1)
+        )
+        self.assertEqual(
+            self.hashes.hashes.find("sha256"), apt_pkg.HashString("SHA256", self.sha256)
+        )
         self.assertRaises(KeyError, self.hashes.hashes.find, "md5")
 
     def test_file(self):
         """hashes: Test apt_pkg.Hashes(file)."""
-        self.assertEqual(self.fhashes.hashes.find("md5sum").hashvalue,
-                         self.md5)
-        self.assertEqual(self.fhashes.hashes.find("md5sum"),
-                         apt_pkg.HashString("MD5Sum", self.md5))
-        self.assertEqual(self.fhashes.hashes.find("sha1"),
-                         apt_pkg.HashString("SHA1", self.sha1))
-        self.assertEqual(self.fhashes.hashes.find("sha256"),
-                         apt_pkg.HashString("SHA256", self.sha256))
+        self.assertEqual(self.fhashes.hashes.find("md5sum").hashvalue, self.md5)
+        self.assertEqual(
+            self.fhashes.hashes.find("md5sum"), apt_pkg.HashString("MD5Sum", self.md5)
+        )
+        self.assertEqual(
+            self.fhashes.hashes.find("sha1"), apt_pkg.HashString("SHA1", self.sha1)
+        )
+        self.assertEqual(
+            self.fhashes.hashes.find("sha256"),
+            apt_pkg.HashString("SHA256", self.sha256),
+        )
 
     def test_unicode(self):
         """hashes: Test apt_pkg.Hashes(unicode)."""
-        if sys.version_info[0] == 3:
-            self.assertRaises(TypeError, apt_pkg.Hashes, "D")
-            self.assertRaises(TypeError, apt_pkg.md5sum, "D")
-            self.assertRaises(TypeError, apt_pkg.sha1sum, "D")
-            self.assertRaises(TypeError, apt_pkg.sha256sum, "D")
-        else:
-            self.assertRaises(TypeError, apt_pkg.Hashes, unicode())
-            self.assertRaises(TypeError, apt_pkg.md5sum, unicode())
-            self.assertRaises(TypeError, apt_pkg.sha1sum, unicode())
-            self.assertRaises(TypeError, apt_pkg.sha256sum, unicode())
+        self.assertRaises(TypeError, apt_pkg.Hashes, "D")
+        self.assertRaises(TypeError, apt_pkg.md5sum, "D")
+        self.assertRaises(TypeError, apt_pkg.sha1sum, "D")
+        self.assertRaises(TypeError, apt_pkg.sha256sum, "D")
 
 
 class TestHashString(testcommon.TestCase):
@@ -131,8 +129,7 @@ class TestHashString(testcommon.TestCase):
     def test_wrong(self):
         """hashes: Test apt_pkg.HashString(wrong_type)."""
         self.assertRaises(TypeError, apt_pkg.HashString, 0)
-        if sys.version_info[0] == 3:
-            self.assertRaises(TypeError, apt_pkg.HashString, bytes())
+        self.assertRaises(TypeError, apt_pkg.HashString, bytes())
 
 
 class TestHashStringList(testcommon.TestCase):
@@ -156,10 +153,8 @@ class TestHashStringList(testcommon.TestCase):
 
     def test_append(self):
         """Testing whether append works correctly."""
-        hs1 = apt_pkg.HashString("MD5Sum",
-                                 "a60599e6200b60050d7a30721e3532ed")
-        hs2 = apt_pkg.HashString("SHA1",
-                                 "ef113338e654b1ada807a939ad47b3a67633391b")
+        hs1 = apt_pkg.HashString("MD5Sum", "a60599e6200b60050d7a30721e3532ed")
+        hs2 = apt_pkg.HashString("SHA1", "ef113338e654b1ada807a939ad47b3a67633391b")
 
         hsl = apt_pkg.HashStringList()
         hsl.append(hs1)
@@ -172,10 +167,8 @@ class TestHashStringList(testcommon.TestCase):
 
     def test_find(self):
         """Testing whether append works correctly."""
-        hs1 = apt_pkg.HashString("MD5Sum",
-                                 "a60599e6200b60050d7a30721e3532ed")
-        hs2 = apt_pkg.HashString("SHA1",
-                                 "ef113338e654b1ada807a939ad47b3a67633391b")
+        hs1 = apt_pkg.HashString("MD5Sum", "a60599e6200b60050d7a30721e3532ed")
+        hs2 = apt_pkg.HashString("SHA1", "ef113338e654b1ada807a939ad47b3a67633391b")
 
         hsl = apt_pkg.HashStringList()
         hsl.append(hs1)
@@ -199,8 +192,7 @@ class TestHashStringList(testcommon.TestCase):
 
         self.assertTrue(hsl.verify_file(apt_pkg.__file__))
 
-        md5sum = apt_pkg.HashString("MD5Sum",
-                                    "a60599e6200b60050d7a30721e3532ed")
+        md5sum = apt_pkg.HashString("MD5Sum", "a60599e6200b60050d7a30721e3532ed")
         hsl.append(md5sum)
 
         self.assertFalse(hsl.verify_file(apt_pkg.__file__))
