@@ -4,7 +4,6 @@
 import os
 import shutil
 import unittest
-import warnings
 
 import apt_inst
 import apt_pkg
@@ -13,11 +12,10 @@ import testcommon
 
 
 class TestPath(testcommon.TestCase):
-
-    dir_unicode = u'data/tmp'
-    dir_bytes = b'data/tmp'
-    file_unicode = u'data/tmp/python-apt-test'
-    file_bytes = b'data/tmp/python-apt-test'
+    dir_unicode = "data/tmp"
+    dir_bytes = b"data/tmp"
+    file_unicode = "data/tmp/python-apt-test"
+    file_bytes = b"data/tmp/python-apt-test"
 
     def setUp(self):
         testcommon.TestCase.setUp(self)
@@ -31,89 +29,80 @@ class TestPath(testcommon.TestCase):
         shutil.rmtree(self.dir_bytes)
 
     def test_acquire(self):
-        apt_pkg.AcquireFile(apt_pkg.Acquire(), "http://example.com",
-                            destdir=self.file_bytes, destfile=self.file_bytes)
-        apt_pkg.AcquireFile(apt_pkg.Acquire(),
-                            "http://example.com",
-                            destdir=self.file_unicode,
-                            destfile=self.file_unicode)
-
-    def test_acquire_file_md5_keyword_backward_compat(self):
-        """
-        Ensure that both "md5" and "hash" is supported as keyword for
-        AcquireFile
-        """
-        with warnings.catch_warnings(record=True) as caught_warnings:
-            warnings.simplefilter("always")
-            apt_pkg.AcquireFile(
-                apt_pkg.Acquire(), "http://example.com",
-                destfile=self.file_bytes,
-                md5="abcdef")
-
-        self.assertEqual(len(caught_warnings), 1)
-        self.assertTrue(issubclass(caught_warnings[0].category,
-                                   DeprecationWarning))
-        self.assertIn("md5", str(caught_warnings[0].message))
-        self.assertIn("hash", str(caught_warnings[0].message))
-
         apt_pkg.AcquireFile(
-            apt_pkg.Acquire(), "http://example.com",
+            apt_pkg.Acquire(),
+            "http://example.com",
+            destdir=self.file_bytes,
             destfile=self.file_bytes,
-            hash="sha1:41050ed528554fdd6c6c9a086ddd6bdba5857b21")
+        )
+        apt_pkg.AcquireFile(
+            apt_pkg.Acquire(),
+            "http://example.com",
+            destdir=self.file_unicode,
+            destfile=self.file_unicode,
+        )
 
     def test_acquire_hashes(self):
         hs = apt_pkg.HashString("d41d8cd98f00b204e9800998ecf8427e")
         hsl = apt_pkg.HashStringList()
         hsl.append(hs)
-        apt_pkg.AcquireFile(apt_pkg.Acquire(),
-                            "http://example.com",
-                            hash=hsl,
-                            destdir=self.file_unicode,
-                            destfile=self.file_unicode)
-        apt_pkg.AcquireFile(apt_pkg.Acquire(),
-                            "http://example.com",
-                            hash=str(hs),
-                            destdir=self.file_unicode,
-                            destfile=self.file_unicode)
-        self.assertRaises(TypeError, apt_pkg.AcquireFile, apt_pkg.Acquire(),
-                            "http://example.com",
-                            hash=hs,
-                            destdir=self.file_unicode,
-                            destfile=self.file_unicode)
+        apt_pkg.AcquireFile(
+            apt_pkg.Acquire(),
+            "http://example.com",
+            hash=hsl,
+            destdir=self.file_unicode,
+            destfile=self.file_unicode,
+        )
+        apt_pkg.AcquireFile(
+            apt_pkg.Acquire(),
+            "http://example.com",
+            hash=str(hs),
+            destdir=self.file_unicode,
+            destfile=self.file_unicode,
+        )
+        self.assertRaises(
+            TypeError,
+            apt_pkg.AcquireFile,
+            apt_pkg.Acquire(),
+            "http://example.com",
+            hash=hs,
+            destdir=self.file_unicode,
+            destfile=self.file_unicode,
+        )
 
     def test_ararchive(self):
-        archive = apt_inst.ArArchive(u"data/test_debs/data-tar-xz.deb")
+        archive = apt_inst.ArArchive("data/test_debs/data-tar-xz.deb")
 
         apt_inst.ArArchive(b"data/test_debs/data-tar-xz.deb")
 
-        archive.extract(u"debian-binary", u"data/tmp")
+        archive.extract("debian-binary", "data/tmp")
         archive.extract(b"debian-binary", b"data/tmp")
-        archive.extractall(u"data/tmp")
+        archive.extractall("data/tmp")
         archive.extractall(b"data/tmp")
-        self.assertEqual(archive.extractdata(u"debian-binary"), b"2.0\n")
+        self.assertEqual(archive.extractdata("debian-binary"), b"2.0\n")
         self.assertEqual(archive.extractdata(b"debian-binary"), b"2.0\n")
-        self.assertTrue(archive.getmember(u"debian-binary"))
+        self.assertTrue(archive.getmember("debian-binary"))
         self.assertTrue(archive.getmember(b"debian-binary"))
-        self.assertTrue(u"debian-binary" in archive)
+        self.assertTrue("debian-binary" in archive)
         self.assertTrue(b"debian-binary" in archive)
         self.assertTrue(archive[b"debian-binary"])
-        self.assertTrue(archive[u"debian-binary"])
+        self.assertTrue(archive["debian-binary"])
 
-        tar = archive.gettar(u"control.tar.xz", "xz")
+        tar = archive.gettar("control.tar.xz", "xz")
         tar = archive.gettar(b"control.tar.xz", "xz")
 
         tar.extractall(self.dir_unicode)
         tar.extractall(self.dir_bytes)
-        self.assertRaises(LookupError, tar.extractdata, u"Do-not-exist")
+        self.assertRaises(LookupError, tar.extractdata, "Do-not-exist")
         self.assertRaises(LookupError, tar.extractdata, b"Do-not-exist")
         tar.extractdata(b"control")
-        tar.extractdata(u"control")
+        tar.extractdata("control")
 
-        apt_inst.TarFile(os.path.join(self.dir_unicode, u"control.tar.xz"))
+        apt_inst.TarFile(os.path.join(self.dir_unicode, "control.tar.xz"))
         apt_inst.TarFile(os.path.join(self.dir_bytes, b"control.tar.xz"))
 
     def test_configuration(self):
-        with open(self.file_unicode, 'w') as config:
+        with open(self.file_unicode, "w") as config:
             config.write("Hello { World 1; };")
         apt_pkg.read_config_file(apt_pkg.config, self.file_bytes)
         apt_pkg.read_config_file(apt_pkg.config, self.file_unicode)
@@ -145,7 +134,7 @@ class TestPath(testcommon.TestCase):
         apt_pkg.config["dir"] = "data/test_debs"
         cache = apt_pkg.Cache(None)
         policy = apt_pkg.Policy(cache)
-        file_unicode = os.path.join(self.dir_unicode, u"test.prefs")
+        file_unicode = os.path.join(self.dir_unicode, "test.prefs")
         file_bytes = os.path.join(self.dir_bytes, b"test.prefs")
 
         self.assertTrue(policy.read_pinfile(file_unicode))
@@ -166,5 +155,5 @@ class TestPath(testcommon.TestCase):
         self.assertRaises(StopIteration, next, tag2)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
