@@ -9,10 +9,10 @@ import testcommon
 
 
 class TestPyflakesClean(testcommon.TestCase):
-
     EXCLUDES = ["build", "tests/old", ".pybuild"]
     TOPLEVEL = os.path.normpath(
-        os.path.join(os.path.dirname(os.path.abspath(__file__)), ".."))
+        os.path.join(os.path.dirname(os.path.abspath(__file__)), "..")
+    )
 
     def is_excluded_path(self, path):
         for exclude in self.EXCLUDES:
@@ -31,7 +31,7 @@ class TestPyflakesClean(testcommon.TestCase):
         return files
 
     def test_pyflakes_clean(self):
-        cmd = ["pyflakes"] + self.get_py_files(self.TOPLEVEL)
+        cmd = ["pyflakes3"] + self.get_py_files(self.TOPLEVEL)
         res = subprocess.call(cmd)
         if res != 0:
             self.fail("pyflakes failed with: %s" % res)
@@ -39,5 +39,6 @@ class TestPyflakesClean(testcommon.TestCase):
 
 if __name__ == "__main__":
     import logging
+
     logging.basicConfig(level=logging.DEBUG)
     unittest.main()
