@@ -86,26 +86,19 @@ class TestSignedUsable(testcommon.TestCase):
         apt.progress.text.AcquireProgress = self.progress
 
     def doInstall(self, name, bargs):
-        install_progress = apt.progress.base.InstallProgress()
         self.cache[name].mark_install()
         try:
-            self.cache.commit(install_progress=install_progress, **bargs)
+            with apt.progress.base.InstallProgress() as ip:
+                self.cache.commit(install_progress=ip, **bargs)
         finally:
-            # Workaround install progress leaking files
-            install_progress.write_stream.close()
-            install_progress.status_stream.close()
             for fname in os.listdir(
                 os.path.join(self.chroot_path, "var/cache/apt/archives")
             ):
                 if os.path.isfile(
-                    os.path.join(
-                        self.chroot_path, "var/cache/apt/archives", fname
-                    )
+                    os.path.join(self.chroot_path, "var/cache/apt/archives", fname)
                 ):
                     os.unlink(
-                        os.path.join(
-                            self.chroot_path, "var/cache/apt/archives", fname
-                        )
+                        os.path.join(self.chroot_path, "var/cache/apt/archives", fname)
                     )
             self.cache[name].mark_keep()
 
@@ -120,9 +113,7 @@ class TestSignedUsable(testcommon.TestCase):
             ):
                 if fname.endswith(".deb"):
                     os.unlink(
-                        os.path.join(
-                            self.chroot_path, "var/cache/apt/archives", fname
-                        )
+                        os.path.join(self.chroot_path, "var/cache/apt/archives", fname)
                     )
             self.cache[name].mark_keep()
 
