@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 #  get_debian_mirrors.py - Parse Mirrors.masterlist and create a mirror list.
 #
 #  Copyright (c) 2010-2011 Julian Andres Klode <jak@debian.org>
@@ -20,26 +20,27 @@
 from __future__ import print_function
 import collections
 import sys
-import urllib2
-from debian_bundle import deb822
+import urllib.request
+from debian import deb822
 
 mirrors = collections.defaultdict(set)
-masterlist = urllib2.urlopen("https://mirror-master.debian.org/"
-                             "status/Mirrors.masterlist")
+masterlist = urllib.request.urlopen(
+    "https://mirror-master.debian.org/" "status/Mirrors.masterlist"
+)
 
 for mirror in deb822.Deb822.iter_paragraphs(masterlist):
     if "Country" not in mirror:
         continue
     country = mirror["Country"].split(None, 1)[0]
     site = mirror["Site"]
-    for proto in 'http', 'ftp':
+    for proto in "http", "ftp":
         if "Archive-%s" % proto in mirror:
-            mirrors[country].add("%s://%s%s" % (proto, site,
-                                                mirror["Archive-%s" % proto]))
+            mirrors[country].add(
+                "%s://%s%s" % (proto, site, mirror["Archive-%s" % proto])
+            )
 
 if len(mirrors) == 0:
-    sys.stderr.write("E: Could not read the mirror list due to "
-                     "some unknown issue\n")
+    sys.stderr.write("E: Could not read the mirror list due to " "some unknown issue\n")
     sys.exit(1)
 for country in sorted(mirrors):
     print("#LOC:%s" % country)
